@@ -21,7 +21,7 @@ class Radiko():
 
    authToken = None
    region = None
-   version = "1.0.1"
+   version = "1.0.2"
 
    def __init__(self):
 
@@ -208,7 +208,4 @@ class Radiko():
       return self.region
 
    def getVersion(self):
-      return self.version
-
-class RadikoException(Exception):
-   pass
\ No newline at end of file
+      return self.version
\ No newline at end of file
